# react-native-barcode
A react-native component to generate barcodes in a WebView canvas.

Utilizes [JsBarcode](https://github.com/lindell/JsBarcode) for barcode generation. Inspired by [react-native-qrcode](https://github.com/cssivision/react-native-qrcode).

## Installation
```sh
npm install react-native-barcode --save
```
## Usage
```jsx
'use strict';

import React, { Component } from 'react'
import Barcode from 'react-native-barcode';

import {
    AppRegistry,
    StyleSheet,
    View,
    TextInput
} from 'react-native';

class HelloWorld extends Component {
  state = {
    text: 'http://facebook.github.io/react-native/',
  };

  render() {
    return (
      <View style={styles.container}>
        <TextInput
          style={styles.input}
          onChangeText={(text) => this.setState({text: text})}
          value={this.state.text}
        />
        <QRCode
          value={this.state.text}
          size={200}
          bgColor='purple'
          fgColor='white'/>
      </View>
    );
  };
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        backgroundColor: 'white',
        alignItems: 'center',
        justifyContent: 'center'
    },

    input: {
        height: 40,
        borderColor: 'gray',
        borderWidth: 1,
        margin: 10,
        borderRadius: 5,
        padding: 5,
    }
});

AppRegistry.registerComponent('HelloWorld', () => HelloWorld);

module.exports = HelloWorld;
```
## Available Props

prop      | type                 | default value
----------|----------------------|--------------
`value`   | `string`             | `http://facebook.github.io/react-native/`
`size`    | `number`             | `128`
`bgColor` | `string` (CSS color) | `"#000"`
`fgColor` | `string` (CSS color) | `"#FFF"`


# Licenses

All source code is licensed under the [MIT License](https://github.com/jcleigh/react-native-barcode/blob/master/LICENSE).
